Learn R Programming

oem (version 1.01)

print.oemfit: print an oemfit object

Description

Print a summary of the oemfit path at each step along the path.

Usage

## S3 method for class 'oemfit'
## S3 method for class 'oemfit':
print(x, digits = max(3, getOption("digits") - 3), ...)

Arguments

x
fitted oemfit object.
digits
significant digits in print out.
...
additional print arguments.

Value

  • The matrix above is silently returned.

Details

The call that produced the object x is printed, followed by a three-column matrix with columns Df, sum of squares and lambda.

References

Xiong, S., Dai, B. and Qian, P. Z. G. (2011), Orthogonalizing Penalized Regression, http://www.stat.wisc.edu/~zhiguang/OEM.pdf

See Also

oemfit, plot.oemfit, predict.oemfit

Examples

Run this code
x=matrix(rnorm(100*20),100,20)
y=rnorm(100)
fit <- oemfit(y~x)
print(fit)

Run the code above in your browser using DataLab